pub enum ProtocolError {
FrameTooLarge {
size: usize,
},
TruncatedFrame,
InvalidLengthPrefix,
FrameLengthOutOfRange {
length: u32,
},
CapacityOverflow,
InvalidDiscard {
count: usize,
buffer_len: usize,
},
Serde(Error),
}Expand description
Errors produced by the Hoy protocol codec.
Variants
FrameTooLarge
The serialized payload length does not fit into a u32 length prefix.
TruncatedFrame
The provided frame contains less bytes than declared in its header.
InvalidLengthPrefix
The provided frame header is malformed.
FrameLengthOutOfRange
The provided frame length cannot be represented by the current platform.
CapacityOverflow
Failed to compute a valid buffer capacity for a frame.
InvalidDiscard
Attempt to discard an invalid number of bytes from a frame buffer.
Serde(Error)
Serialization or deserialization error.