FrameBuffer

Struct FrameBuffer 

pub struct FrameBuffer { /* private fields */ }
Incremental buffer for decoding length-prefixed protocol frames.

Implementations

Source

impl FrameBuffer

pub const fn new() -> Self

Default frame buffer constructor.

pub fn with_capacity(capacity: usize) -> Self

Construct an empty frame buffer with a preallocated capacity.

pub fn append(&mut self, chunk: &[u8]) -> Result<(), ProtocolError>

Append a new chunk of transported bytes to buffer.

Arguments
  • chunk: array of bytes to append.
Returns

Ok(()) on succesfull byte insertion.

Errors

Returns ProtocolError if buffer would overflow.

pub fn try_decode<T>(&mut self) -> Result<Option<T>, ProtocolError>

Attempt to decode a single frame from the buffer.

If a complete frame is available, it is decoded and then removed from the internal buffer.

If the buffer does not yet contain a full frame, no data is discarded from the buffer.

Returns
  • Ok(None) - if no complete frame available in the buffer,
  • decoded frame value - if a full frame is present in the buffer and succesfully decoded.
Errors

Returns ProtocolError if:

  • buffer data contains a malformed complete frame,
  • frame length is out of range,
  • deserialization fails.
pub fn len(&self) -> usize

Returns the number of currently buffered bytes.

pub fn is_empty(&self) -> bool

Returns true if buffer empty, false otherwise.

pub fn clear(&mut self)

Clears buffer - removes all buffered bytes.

pub fn as_slice(&self) -> &[u8]

Returns a read-only view of buffered bytes.