pub struct FrameBuffer { /* private fields */ }Expand description
Incremental buffer for decoding length-prefixed protocol frames.
Implementations
Sourceimpl FrameBuffer
impl FrameBuffer
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Construct an empty frame buffer with a preallocated capacity.
Sourcepub fn try_decode<T>(&mut self) -> Result<Option<T>, ProtocolError>where
T: DeserializeOwned,
pub fn try_decode<T>(&mut self) -> Result<Option<T>, ProtocolError>where
T: DeserializeOwned,
Attempt to decode a single frame from the buffer.
If a complete frame is available, it is decoded and then removed from the internal buffer.
If the buffer does not yet contain a full frame, no data is discarded from the buffer.
Returns
Ok(None)- if no complete frame available in the buffer,- decoded frame value - if a full frame is present in the buffer and succesfully decoded.
Errors
Returns ProtocolError if:
- buffer data contains a malformed complete frame,
- frame length is out of range,
- deserialization fails.